#**********************************************************************
#                    hanko.tcl
#                 ================
#                 Uwe Berger; 2010
#
# Simulation der Zeitanzeige einer Tokyoflash-Uhr vom Typ Hanko.
# (http://www.tokyoflash.com)
#
#
# ---------
# Have fun!
#
#**********************************************************************
package require Tk

set gvar(dx)		250
set gvar(dy)		$gvar(dx)
set gvar(led_dm)	20
set gvar(color_off)	gray10
set gvar(color_m5)	red
set gvar(color_m1)	green
set gvar(color_h6)	green
set gvar(color_h1)	yellow


set gvar(old_m)		60
set pi 3.1415926535897931
set 2pi [expr $pi*2]

#***************************
proc clear_leds {} {
	global gvar
	.clock itemconfigure led -fill $gvar(color_off) -outline $gvar(color_off)
}

#***************************
proc circle {c r b t} {
	global gvar 2pi
	for {set i 0} {$i<$c} {incr i} {
		# Element (im Kreis) zeichnen
		.clock create oval	[expr $gvar(dx)/2-$gvar(led_dm)/2+$r*sin(($2pi/$c)*$i+$b)]\
							[expr $gvar(dy)/2-$gvar(led_dm)/2+$r*cos(($2pi/$c)*$i+$b)*(-1)]\
							[expr $gvar(dx)/2-$gvar(led_dm)/2+$r*sin(($2pi/$c)*$i+$b)+$gvar(led_dm)]\
							[expr $gvar(dy)/2-$gvar(led_dm)/2+$r*cos(($2pi/$c)*$i+$b)*(-1)+$gvar(led_dm)]\
							-outline $gvar(color_off)\
							-fill $gvar(color_off)\
							-tags [list $t$i $t led]
	}
}

#***************************
proc takt {} {
	global gvar
	# Uhrzeit ermitteln
	set s [scan [clock format [clock seconds] -format %S] %d]
	set m [scan [clock format [clock seconds] -format %M] %d]
	set h [scan [clock format [clock seconds] -format %H] %d]
	if {$gvar(old_m) != $m} {
		set gvar(old_m) $m
		# 12h-Anzeige...
		if {$h > 12} {set h [expr $h-12]}
		# Uhrzeit ausgeben...
		clear_leds
		# ...5er Minuten (hier ist das Original etwas inkonsequent: es gibt
		# zwar eine 0.Stelle, aber die leuchtet nicht bei <5min...) 
		if {[expr $m/5]>0} {
			.clock itemconfigure m5[expr $m/5] -fill $gvar(color_m5) -outline $gvar(color_m5)
		}
		# ...1er Minuten
		.clock itemconfigure m1[expr ($m%5)-1] -fill $gvar(color_m1) -outline $gvar(color_m1)
		# ...Stunde < 6
		.clock itemconfigure h1[expr ($h%6)-1] -fill $gvar(color_h1) -outline $gvar(color_h1)
		# ...Stunde > 6
		if {$h>6} {.clock itemconfigure h60 -fill $gvar(color_h6) -outline $gvar(color_h6)}
	}
	# Prozedur nach 1 Sekunde neu aufrufen	
	after 1000 takt
}

#***************************
proc gui {} {
	global gvar pi
	wm title . "Tokyoflash Hanko" 
	wm resizable . 0 0
	canvas	.clock -width $gvar(dx) -height $gvar(dy) -bg black -bd 0
	pack .clock 
	circle 12 100 0 m5
	circle 4 71 [expr $pi/4] m1
	circle 6 25 [expr $pi/3] h1
	circle 1 0 0 h6
}

#***************************
#***************************
#***************************
gui
takt




